#
# spec file for package python-sphinxcontrib-plantuml
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-sphinxcontrib-plantuml
Version:        0.30
Release:        1.2
Summary:        Sphinx API for Web Apps
License:        BSD-2-Clause
URL:            https://github.com/sphinx-contrib/plantuml/
Source:         https://github.com/sphinx-contrib/plantuml/archive/%{version}.tar.gz#/sphinxcontrib-plantuml-%{version}.tar.gz
Patch0:         py3-for-tests.patch
BuildRequires:  %{python_module Sphinx >= 2}
BuildRequires:  %{python_module Sphinx-latex}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  ghostscript
BuildRequires:  python-rpm-macros
BuildRequires:  texlive-epstopdf
Requires:       plantuml
Requires:       python-Sphinx >= 2
BuildArch:      noarch
%python_subpackages

%description
Once you enable this extension, a very simple string like this:

    "Alice -> Bob: Hi!"

will create a nice UML schema. WIth PlantUML, you can specify things like height, width, scale, caption and so on. For details, please see PlantUML documentation at: http://plantuml.sourceforge.net/.

%prep
%autosetup -p1 -n plantuml-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# upstream knows: https://github.com/sphinx-contrib/plantuml/commit/e1b3f7e709eae0e95c70564a7e42279db08c8447
# s/class="figure"/class="figure align-default"/ in test_functional.py
%pytest -k 'not test_buildhtml_name'

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/sphinxcontrib/plantuml.py
%dir %{python_sitelib}/sphinxcontrib/__pycache__
%pycache_only %{python_sitelib}/sphinxcontrib/__pycache__/plantuml.*.py*
%{python_sitelib}/sphinxcontrib_plantuml-%{version}.dist-info
%{python_sitelib}/sphinxcontrib_plantuml-%{version}-py3.*-nspkg.pth

%changelog
* Sat Jun 29 2024 Dirk Müller <dmueller@suse.com>
- update to 0.30:
  * improved pytest 8.1.1 compatibilitiy
  * use SVG format for generating images
* Wed Mar 13 2024 Dirk Müller <dmueller@suse.com>
- update to 0.29:
  * fix deprecation warning during batch processing
  * fix markdown-ness in README
  * pass max width to latex adjustbox
* Thu Mar  7 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup macro.
- Slightly less mess in %%files.
* Fri Dec 29 2023 Dirk Müller <dmueller@suse.com>
- update to 0.27:
  * add svg width height properties, override SVG style
  * reformat sources with black, adjust flake8 rules accordingly
  * remove redundant wheel dep from pyproject.toml
  * create output file with unique file name
* Mon Dec  5 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.24.1
  * Add Sphinx Extension classifier
* Fri Oct  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version to 0.24
  * allow whitespace in arguments (fixes #66)
- Update to version to 0.23
  * work around native/non-native sphinxcontrib package conflicts on github CI
  * Add adjustbox to change width, height and scale
  * Initial attempt to add TikZ
* Tue Jun 29 2021 Linnaea Lavia <obs@lavia.moe>
- Version update to 0.21, drops python2
  * py3-for-tests.patch: refreshed
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to call tests using python3 not python2:
  * py3-for-tests.patch
* Fri Mar  6 2020 pgajdos@suse.com
- version update to 0.18
  * no upstream changelog
* Mon Sep  2 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.17.1:
  * distribute license file
* Fri Aug 30 2019 Andreas Hasenkopf <ahasenkopf@suse.com>
- Updated to 0.17
* Fri Jan 11 2019 ahasenkopf@suse.com
- Version 0.14
